# -*- coding: utf-8 -*-

"""Top-level package for wcraas_control."""

__author__ = """Kolokotronis Panagiotis"""
__email__ = "panagiks@gmail.com"
__version__ = "__version__ = '0.1.2'"

from wcraas_control.config import Config  # NOQA
from wcraas_control.wcraas_control import ControlWorker  # NOQA
